@@ -29,8 +29,10 @@ from .incident_response_body_type import IncidentResponseBodyType
 from .incident_response_body_visibility import IncidentResponseBodyVisibility
 from .incident_role_assignment_response_body import IncidentRoleAssignmentResponseBody
 from .incident_role_response_body import IncidentRoleResponseBody
+from .incident_role_response_body_role_type import IncidentRoleResponseBodyRoleType
 from .incident_roles_list_response_body import IncidentRolesListResponseBody
 from .incident_roles_show_response_body import IncidentRolesShowResponseBody
+from .incident_timestamp_response_body import IncidentTimestampResponseBody
 from .incidents_create_request_body import IncidentsCreateRequestBody
 from .incidents_create_request_body_visibility import (
     IncidentsCreateRequestBodyVisibility,
