@@ -12,6 +12,7 @@ from ..models.incident_response_body_visibility import IncidentResponseBodyVisib
 from ..models.incident_role_assignment_response_body import (
     IncidentRoleAssignmentResponseBody,
 )
+from ..models.incident_timestamp_response_body import IncidentTimestampResponseBody
 from ..models.severity_response_body import SeverityResponseBody
 from ..types import UNSET, Unset
 
@@ -22,21 +23,9 @@ T = TypeVar("T", bound="IncidentResponseBody")
 class IncidentResponseBody:
     """
     Example:
-        {'call_url': 'https://zoom.us/foo', 'closed_at': '2021-08-17T13:28:57.801578Z', 'created_at':
-            '2021-08-17T13:28:57.801578Z', 'custom_field_entries': [{'custom_field': {'description': 'Which team is impacted
-            by this issue', 'field_type': 'single_select', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Affected Team',
-            'options': [{'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key':
-            10, 'value': 'Product'}, {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'sort_key': 10, 'value': 'Product'}]}, 'values': [{'value_link': 'https://google.com/', 'value_numeric':
-            '123.456', 'value_option': {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'sort_key': 10, 'value': 'Product'}, 'value_text': 'This is my text field, I hope you like it'}, {'value_link':
-            'https://google.com/', 'value_numeric': '123.456', 'value_option': {'custom_field_id':
-            '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'},
-            'value_text': 'This is my text field, I hope you like it'}, {'value_link': 'https://google.com/',
-            'value_numeric': '123.456', 'value_option': {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id':
-            '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}, 'value_text': 'This is my text field, I hope
-            you like it'}]}, {'custom_field': {'description': 'Which team is impacted by this issue', 'field_type':
-            'single_select', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Affected Team', 'options': [{'custom_field_id':
+        {'call_url': 'https://zoom.us/foo', 'created_at': '2021-08-17T13:28:57.801578Z', 'custom_field_entries':
+            [{'custom_field': {'description': 'Which team is impacted by this issue', 'field_type': 'single_select', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Affected Team', 'options': [{'custom_field_id':
             '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'},
             {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value':
             'Product'}]}, 'values': [{'value_link': 'https://google.com/', 'value_numeric': '123.456', 'value_option':
@@ -58,41 +47,34 @@ class IncidentResponseBody:
             '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}, 'value_text': 'This is my text field, I hope
             you like it'}, {'value_link': 'https://google.com/', 'value_numeric': '123.456', 'value_option':
             {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value':
-            'Product'}, 'value_text': 'This is my text field, I hope you like it'}]}, {'custom_field': {'description':
-            'Which team is impacted by this issue', 'field_type': 'single_select', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'name': 'Affected Team', 'options': [{'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id':
-            '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}, {'custom_field_id':
-            '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}]},
-            'values': [{'value_link': 'https://google.com/', 'value_numeric': '123.456', 'value_option': {'custom_field_id':
-            '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'},
-            'value_text': 'This is my text field, I hope you like it'}, {'value_link': 'https://google.com/',
-            'value_numeric': '123.456', 'value_option': {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id':
-            '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}, 'value_text': 'This is my text field, I hope
-            you like it'}, {'value_link': 'https://google.com/', 'value_numeric': '123.456', 'value_option':
-            {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value':
-            'Product'}, 'value_text': 'This is my text field, I hope you like it'}]}], 'external_id': 123, 'fixed_at':
-            '2021-08-17T13:28:57.801578Z', 'id': '01FDAG4SAP5TYPT98WGR2N7W91', 'identified_at':
-            '2021-08-17T13:28:57.801578Z', 'name': 'Our database is sad', 'postmortem_document_url':
-            'https://docs.google.com/my_doc_id', 'reported_at': '2021-08-17T13:28:57.801578Z', 'reporter': {'api_key':
-            {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'My test API key'}, 'user': {'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'name': 'Lisa Karlin Curtis', 'role': 'viewer'}}, 'roles': [{'assignee': {'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z',
-            'description': 'The person currently coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
-            'instructions': 'Take point on the incident; Make sure people are clear on responsibilities', 'lead_role': True,
-            'name': 'Incident Lead', 'required': True, 'shortform': 'lead', 'updated_at': '2021-08-17T13:28:57.801578Z'}},
-            {'assignee': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role':
-            {'created_at': '2021-08-17T13:28:57.801578Z', 'description': 'The person currently coordinating the incident',
-            'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident; Make sure people are clear on
-            responsibilities', 'lead_role': True, 'name': 'Incident Lead', 'required': True, 'shortform': 'lead',
+            'Product'}, 'value_text': 'This is my text field, I hope you like it'}]}], 'id': '01FDAG4SAP5TYPT98WGR2N7W91',
+            'incident_role_assignments': [{'assignee': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis',
+            'role': 'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z', 'description': 'The person currently
+            coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident;
+            Make sure people are clear on responsibilities', 'name': 'Incident Lead', 'required': True, 'role_type': 'lead',
+            'shortform': 'lead', 'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at':
+            '2021-08-17T13:28:57.801578Z', 'description': 'The person currently coordinating the incident', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident; Make sure people are clear on
+            responsibilities', 'name': 'Incident Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead',
             'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa
             Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z', 'description': 'The
             person currently coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on
-            the incident; Make sure people are clear on responsibilities', 'lead_role': True, 'name': 'Incident Lead',
-            'required': True, 'shortform': 'lead', 'updated_at': '2021-08-17T13:28:57.801578Z'}}], 'severity':
-            {'created_at': '2021-08-17T13:28:57.801578Z', 'description': "It's not really that bad, everyone chill", 'id':
-            '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Minor', 'rank': 1, 'updated_at': '2021-08-17T13:28:57.801578Z'},
-            'slack_channel_name': 'inc-165-green-parrot', 'status': 'investigating', 'summary': "Our database is really
-            really sad, and we don't know why yet.", 'summary_updated_at': '2021-08-17T13:28:57.801578Z', 'type': 'real',
+            the incident; Make sure people are clear on responsibilities', 'name': 'Incident Lead', 'required': True,
+            'role_type': 'lead', 'shortform': 'lead', 'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at':
+            '2021-08-17T13:28:57.801578Z', 'description': 'The person currently coordinating the incident', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident; Make sure people are clear on
+            responsibilities', 'name': 'Incident Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead',
+            'updated_at': '2021-08-17T13:28:57.801578Z'}}], 'name': 'Our database is sad', 'postmortem_document_url':
+            'https://docs.google.com/my_doc_id', 'reference': 'INC-123', 'reporter': {'api_key': {'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'My test API key'}, 'user': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name':
+            'Lisa Karlin Curtis', 'role': 'viewer'}}, 'severity': {'created_at': '2021-08-17T13:28:57.801578Z',
+            'description': "It's not really that bad, everyone chill", 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Minor',
+            'rank': 1, 'updated_at': '2021-08-17T13:28:57.801578Z'}, 'slack_channel_id': 'C02AW36C1M5',
+            'slack_channel_name': 'inc-165-green-parrot', 'status': 'triage', 'summary': "Our database is really really sad,
+            and we don't know why yet.", 'timestamps': [{'last_occurred_at': '2021-08-17T13:28:57.801578Z', 'name':
+            'last_activity'}, {'last_occurred_at': '2021-08-17T13:28:57.801578Z', 'name': 'last_activity'}], 'type': 'real',
             'updated_at': '2021-08-17T13:28:57.801578Z', 'visibility': 'public'}
 
     Attributes:
@@ -122,68 +104,68 @@ class IncidentResponseBody:
             you like it'}, {'value_link': 'https://google.com/', 'value_numeric': '123.456', 'value_option':
             {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value':
             'Product'}, 'value_text': 'This is my text field, I hope you like it'}]}].
-        external_id (int): External identifier for the incident - often displayed with an INC- prefix Example: 123.
         id (str): Unique identifier for the incident Example: 01FDAG4SAP5TYPT98WGR2N7W91.
-        name (str): Explanation of the incident Example: Our database is sad.
-        reported_at (datetime.datetime): When the incident was reported Example: 2021-08-17T13:28:57.801578Z.
-        reporter (ActorResponseBody):  Example: {'api_key': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'My test API
-            key'}, 'user': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}}.
-        roles (List[IncidentRoleAssignmentResponseBody]): A list of who is assigned to each role for this incident
-            Example: [{'assignee': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'},
-            'role': {'created_at': '2021-08-17T13:28:57.801578Z', 'description': 'The person currently coordinating the
-            incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident; Make sure people are
-            clear on responsibilities', 'lead_role': True, 'name': 'Incident Lead', 'required': True, 'shortform': 'lead',
-            'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa
-            Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z', 'description': 'The
-            person currently coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on
-            the incident; Make sure people are clear on responsibilities', 'lead_role': True, 'name': 'Incident Lead',
-            'required': True, 'shortform': 'lead', 'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'id':
+        incident_role_assignments (List[IncidentRoleAssignmentResponseBody]): A list of who is assigned to each role for
+            this incident Example: [{'assignee': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role':
+            'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z', 'description': 'The person currently
+            coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident;
+            Make sure people are clear on responsibilities', 'name': 'Incident Lead', 'required': True, 'role_type': 'lead',
+            'shortform': 'lead', 'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'id':
             '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at':
             '2021-08-17T13:28:57.801578Z', 'description': 'The person currently coordinating the incident', 'id':
             '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident; Make sure people are clear on
-            responsibilities', 'lead_role': True, 'name': 'Incident Lead', 'required': True, 'shortform': 'lead',
+            responsibilities', 'name': 'Incident Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead',
+            'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa
+            Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at': '2021-08-17T13:28:57.801578Z', 'description': 'The
+            person currently coordinating the incident', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on
+            the incident; Make sure people are clear on responsibilities', 'name': 'Incident Lead', 'required': True,
+            'role_type': 'lead', 'shortform': 'lead', 'updated_at': '2021-08-17T13:28:57.801578Z'}}, {'assignee': {'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}, 'role': {'created_at':
+            '2021-08-17T13:28:57.801578Z', 'description': 'The person currently coordinating the incident', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'instructions': 'Take point on the incident; Make sure people are clear on
+            responsibilities', 'name': 'Incident Lead', 'required': True, 'role_type': 'lead', 'shortform': 'lead',
             'updated_at': '2021-08-17T13:28:57.801578Z'}}].
+        name (str): Explanation of the incident Example: Our database is sad.
+        reference (str): Reference to this incident, as displayed across the product Example: INC-123.
+        reporter (ActorResponseBody):  Example: {'api_key': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'My test API
+            key'}, 'user': {'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Lisa Karlin Curtis', 'role': 'viewer'}}.
         severity (SeverityResponseBody):  Example: {'created_at': '2021-08-17T13:28:57.801578Z', 'description': "It's
             not really that bad, everyone chill", 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'name': 'Minor', 'rank': 1,
             'updated_at': '2021-08-17T13:28:57.801578Z'}.
-        status (IncidentResponseBodyStatus): Current status of the incident Example: investigating.
+        slack_channel_id (str): ID of the Slack channel in the organisation Slack workspace Example: C02AW36C1M5.
+        status (IncidentResponseBodyStatus): Current status of the incident Example: triage.
         type (IncidentResponseBodyType): Whether the incident is real, a test, or a tutorial Example: real.
         updated_at (datetime.datetime): When the incident was last updated Example: 2021-08-17T13:28:57.801578Z.
         visibility (IncidentResponseBodyVisibility): Whether the incident is public or private Example: public.
         call_url (Union[Unset, str]): The call URL attached to this incident Example: https://zoom.us/foo.
-        closed_at (Union[Unset, datetime.datetime]): When the incident was closed Example: 2021-08-17T13:28:57.801578Z.
-        fixed_at (Union[Unset, datetime.datetime]): When the incident was fixed Example: 2021-08-17T13:28:57.801578Z.
-        identified_at (Union[Unset, datetime.datetime]): When the incident was identified Example:
-            2021-08-17T13:28:57.801578Z.
         postmortem_document_url (Union[Unset, str]): Description of the incident Example:
             https://docs.google.com/my_doc_id.
         slack_channel_name (Union[Unset, str]): Name of the slack channel Example: inc-165-green-parrot.
         summary (Union[Unset, str]): Detailed description of the incident Example: Our database is really really sad,
             and we don't know why yet..
-        summary_updated_at (Union[Unset, str]): When the summary was last updated Example: 2021-08-17T13:28:57.801578Z.
+        timestamps (Union[Unset, List[IncidentTimestampResponseBody]]): Incident lifecycle events and when they last
+            occurred Example: [{'last_occurred_at': '2021-08-17T13:28:57.801578Z', 'name': 'last_activity'},
+            {'last_occurred_at': '2021-08-17T13:28:57.801578Z', 'name': 'last_activity'}].
     """
 
     created_at: datetime.datetime
     custom_field_entries: List[CustomFieldEntryResponseBody]
-    external_id: int
     id: str
+    incident_role_assignments: List[IncidentRoleAssignmentResponseBody]
     name: str
-    reported_at: datetime.datetime
+    reference: str
     reporter: ActorResponseBody
-    roles: List[IncidentRoleAssignmentResponseBody]
     severity: SeverityResponseBody
+    slack_channel_id: str
     status: IncidentResponseBodyStatus
     type: IncidentResponseBodyType
     updated_at: datetime.datetime
     visibility: IncidentResponseBodyVisibility
     call_url: Union[Unset, str] = UNSET
-    closed_at: Union[Unset, datetime.datetime] = UNSET
-    fixed_at: Union[Unset, datetime.datetime] = UNSET
-    identified_at: Union[Unset, datetime.datetime] = UNSET
     postmortem_document_url: Union[Unset, str] = UNSET
     slack_channel_name: Union[Unset, str] = UNSET
     summary: Union[Unset, str] = UNSET
-    summary_updated_at: Union[Unset, str] = UNSET
+    timestamps: Union[Unset, List[IncidentTimestampResponseBody]] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -195,21 +177,20 @@ class IncidentResponseBody:
 
             custom_field_entries.append(custom_field_entries_item)
 
-        external_id = self.external_id
         id = self.id
+        incident_role_assignments = []
+        for incident_role_assignments_item_data in self.incident_role_assignments:
+            incident_role_assignments_item = incident_role_assignments_item_data.to_dict()
+
+            incident_role_assignments.append(incident_role_assignments_item)
+
         name = self.name
-        reported_at = self.reported_at.isoformat()
-
+        reference = self.reference
         reporter = self.reporter.to_dict()
 
-        roles = []
-        for roles_item_data in self.roles:
-            roles_item = roles_item_data.to_dict()
-
-            roles.append(roles_item)
-
         severity = self.severity.to_dict()
 
+        slack_channel_id = self.slack_channel_id
         status = self.status.value
 
         type = self.type.value
@@ -219,22 +200,16 @@ class IncidentResponseBody:
         visibility = self.visibility.value
 
         call_url = self.call_url
-        closed_at: Union[Unset, str] = UNSET
-        if not isinstance(self.closed_at, Unset):
-            closed_at = self.closed_at.isoformat()
-
-        fixed_at: Union[Unset, str] = UNSET
-        if not isinstance(self.fixed_at, Unset):
-            fixed_at = self.fixed_at.isoformat()
-
-        identified_at: Union[Unset, str] = UNSET
-        if not isinstance(self.identified_at, Unset):
-            identified_at = self.identified_at.isoformat()
-
         postmortem_document_url = self.postmortem_document_url
         slack_channel_name = self.slack_channel_name
         summary = self.summary
-        summary_updated_at = self.summary_updated_at
+        timestamps: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.timestamps, Unset):
+            timestamps = []
+            for timestamps_item_data in self.timestamps:
+                timestamps_item = timestamps_item_data.to_dict()
+
+                timestamps.append(timestamps_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -242,13 +217,13 @@ class IncidentResponseBody:
             {
                 "created_at": created_at,
                 "custom_field_entries": custom_field_entries,
-                "external_id": external_id,
                 "id": id,
+                "incident_role_assignments": incident_role_assignments,
                 "name": name,
-                "reported_at": reported_at,
+                "reference": reference,
                 "reporter": reporter,
-                "roles": roles,
                 "severity": severity,
+                "slack_channel_id": slack_channel_id,
                 "status": status,
                 "type": type,
                 "updated_at": updated_at,
@@ -257,20 +232,14 @@ class IncidentResponseBody:
         )
         if call_url is not UNSET:
             field_dict["call_url"] = call_url
-        if closed_at is not UNSET:
-            field_dict["closed_at"] = closed_at
-        if fixed_at is not UNSET:
-            field_dict["fixed_at"] = fixed_at
-        if identified_at is not UNSET:
-            field_dict["identified_at"] = identified_at
         if postmortem_document_url is not UNSET:
             field_dict["postmortem_document_url"] = postmortem_document_url
         if slack_channel_name is not UNSET:
             field_dict["slack_channel_name"] = slack_channel_name
         if summary is not UNSET:
             field_dict["summary"] = summary
-        if summary_updated_at is not UNSET:
-            field_dict["summary_updated_at"] = summary_updated_at
+        if timestamps is not UNSET:
+            field_dict["timestamps"] = timestamps
 
         return field_dict
 
@@ -288,25 +257,27 @@ class IncidentResponseBody:
 
             custom_field_entries.append(custom_field_entries_item)
 
-        external_id = d.pop("external_id")
-
         id = d.pop("id")
 
+        incident_role_assignments = []
+        _incident_role_assignments = d.pop("incident_role_assignments")
+        for incident_role_assignments_item_data in _incident_role_assignments:
+            incident_role_assignments_item = IncidentRoleAssignmentResponseBody.from_dict(
+                incident_role_assignments_item_data
+            )
+
+            incident_role_assignments.append(incident_role_assignments_item)
+
         name = d.pop("name")
 
-        reported_at = isoparse(d.pop("reported_at"))
+        reference = d.pop("reference")
 
         reporter = ActorResponseBody.from_dict(d.pop("reporter"))
 
-        roles = []
-        _roles = d.pop("roles")
-        for roles_item_data in _roles:
-            roles_item = IncidentRoleAssignmentResponseBody.from_dict(roles_item_data)
-
-            roles.append(roles_item)
-
         severity = SeverityResponseBody.from_dict(d.pop("severity"))
 
+        slack_channel_id = d.pop("slack_channel_id")
+
         status = IncidentResponseBodyStatus(d.pop("status"))
 
         type = IncidentResponseBodyType(d.pop("type"))
@@ -317,57 +288,38 @@ class IncidentResponseBody:
 
         call_url = d.pop("call_url", UNSET)
 
-        _closed_at = d.pop("closed_at", UNSET)
-        closed_at: Union[Unset, datetime.datetime]
-        if isinstance(_closed_at, Unset):
-            closed_at = UNSET
-        else:
-            closed_at = isoparse(_closed_at)
-
-        _fixed_at = d.pop("fixed_at", UNSET)
-        fixed_at: Union[Unset, datetime.datetime]
-        if isinstance(_fixed_at, Unset):
-            fixed_at = UNSET
-        else:
-            fixed_at = isoparse(_fixed_at)
-
-        _identified_at = d.pop("identified_at", UNSET)
-        identified_at: Union[Unset, datetime.datetime]
-        if isinstance(_identified_at, Unset):
-            identified_at = UNSET
-        else:
-            identified_at = isoparse(_identified_at)
-
         postmortem_document_url = d.pop("postmortem_document_url", UNSET)
 
         slack_channel_name = d.pop("slack_channel_name", UNSET)
 
         summary = d.pop("summary", UNSET)
 
-        summary_updated_at = d.pop("summary_updated_at", UNSET)
+        timestamps = []
+        _timestamps = d.pop("timestamps", UNSET)
+        for timestamps_item_data in _timestamps or []:
+            timestamps_item = IncidentTimestampResponseBody.from_dict(timestamps_item_data)
+
+            timestamps.append(timestamps_item)
 
         incident_response_body = cls(
             created_at=created_at,
             custom_field_entries=custom_field_entries,
-            external_id=external_id,
             id=id,
+            incident_role_assignments=incident_role_assignments,
             name=name,
-            reported_at=reported_at,
+            reference=reference,
             reporter=reporter,
-            roles=roles,
             severity=severity,
+            slack_channel_id=slack_channel_id,
             status=status,
             type=type,
             updated_at=updated_at,
             visibility=visibility,
             call_url=call_url,
-            closed_at=closed_at,
-            fixed_at=fixed_at,
-            identified_at=identified_at,
             postmortem_document_url=postmortem_document_url,
             slack_channel_name=slack_channel_name,
             summary=summary,
-            summary_updated_at=summary_updated_at,
+            timestamps=timestamps,
         )
 
         incident_response_body.additional_properties = d
